import os
import dotenv

dotenv.load_dotenv(dotenv.find_dotenv())


TINY_DB_PATH = os.getenv('TINY_DB_PATH', 'db.json')

PYQQQ_API_URL = "https://qupiato.com/api"

PYQQQ_API_KEY = os.getenv("PYQQQ_API_KEY")

CREDENTIAL_FILE_PATH = os.path.expanduser("~/.qred")

GOOGLE_CLOUD_LOGGING_ENABLED = (
    os.getenv("GOOGLE_CLOUD_LOGGING_ENABLED", "false") == "true"
)



from typing import Dict, List
import datetime as dtm
import pandas as pd
import tempfile

from google.cloud.storage import Client


def get_tick_data(date: dtm.date, asset_code: str) -> pd.DataFrame:
    """
    해당 일 체결 정보를 반환합니다

    Args:
        date (dtm.date): 조회할 날짜
        asset_code (str): 조회할 종목 코드

    Returns:
        pd.DataFrame: 요청한 일자의 해당 종목의 모든 체결 정보를 담은 DataFrame
    """

    storage_client = Client()
    bucket = storage_client.get_bucket("pyqqq-tick-data")
    blob = bucket.blob(f"{date}/{asset_code}.csv.xz")

    with tempfile.NamedTemporaryFile() as tmpfile:
        blob.download_to_filename(tmpfile.name)
        df = pd.read_csv(tmpfile.name, compression="xz")

    return df



import pyqqq.config as c
import os


def get_api_key() -> str | None:
    if c.PYQQQ_API_KEY:
        return c.PYQQQ_API_KEY

    elif os.path.exists(c.CREDENTIAL_FILE_PATH):
        with open(c.CREDENTIAL_FILE_PATH, "r") as f:
            return f.read().strip()

    return None
